==> org.eclipse.team.svn.core.source_4.8.0.v20220904-1901.jar: org/eclipse/team/svn/core/operation/SVNNullProgressMonitor.java <==
/*******************************************************************************
 * Copyright (c) 2005-2008 Polarion Software.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Alexander Gurov - Initial API and implementation
 *******************************************************************************/

package org.eclipse.team.svn.core.operation;

import java.util.ArrayList;
import java.util.Collection;

import org.eclipse.team.svn.core.connector.ISVNProgressMonitor;
import org.eclipse.team.svn.core.connector.SVNCommitStatus;

/**
 * Empty implementation of the IProgressMonitor interface
 * 
 * @author Alexander Gurov
 */
public class SVNNullProgressMonitor implements ISVNProgressMonitor {
	protected ArrayList<SVNCommitStatus> commitStatuses = new ArrayList<SVNCommitStatus>();
	
	public Collection<SVNCommitStatus> getCommitStatuses() {
		return this.commitStatuses;
	}

	public Collection<SVNCommitStatus> getPostCommitErrors() {
		ArrayList<SVNCommitStatus> retVal = new ArrayList<SVNCommitStatus>();
		for (SVNCommitStatus status : this.commitStatuses) {
			retVal.add(status);
		}
		return retVal;
	}

	public void progress(int current, int total, ItemState state) {

	}

	public boolean isActivityCancelled() {
		return false;
	}

	public void commitStatus(SVNCommitStatus status) {
		this.commitStatuses.add(status);
	}
	
}

==> org.eclipse.team.svn.core.source_5.0.0.v20250112-1244.jar: org/eclipse/team/svn/core/operation/SVNNullProgressMonitor.java <==
/*******************************************************************************
 * Copyright (c) 2005, 2023 Polarion Software and others.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0
 * 
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *    Alexander Gurov - Initial API and implementation
 *    Alexander Fedorov (ArSysOp) - ongoing support
 *******************************************************************************/

package org.eclipse.team.svn.core.operation;

import java.util.ArrayList;
import java.util.Collection;

import org.eclipse.team.svn.core.connector.ISVNProgressMonitor;
import org.eclipse.team.svn.core.connector.SVNCommitStatus;

/**
 * Empty implementation of the IProgressMonitor interface
 * 
 * @author Alexander Gurov
 */
public class SVNNullProgressMonitor implements ISVNProgressMonitor {
	protected ArrayList<SVNCommitStatus> commitStatuses = new ArrayList<>();

	public Collection<SVNCommitStatus> getCommitStatuses() {
		return commitStatuses;
	}

	public Collection<SVNCommitStatus> getPostCommitErrors() {
		ArrayList<SVNCommitStatus> retVal = new ArrayList<>(commitStatuses);
		return retVal;
	}

	@Override
	public void progress(int current, int total, ItemState state) {

	}

	@Override
	public boolean isActivityCancelled() {
		return false;
	}

	@Override
	public void commitStatus(SVNCommitStatus status) {
		commitStatuses.add(status);
	}

}
